@@ -1,9 +1,8 @@
 use Renard::Curie::Setup;
 package Renard::Curie::Component::AccelMap;
 # ABSTRACT: Set up the accelerator map (global keybindings)
-$Renard::Curie::Component::AccelMap::VERSION = '0.001_01'; # TRIAL
-
-$Renard::Curie::Component::AccelMap::VERSION = '0.00101';use Moo;
+$Renard::Curie::Component::AccelMap::VERSION = '0.001';
+use Moo;
 use Function::Parameters;
 
 method BUILD {
@@ -44,7 +43,7 @@ Renard::Curie::Component::AccelMap - Set up the accelerator map (global keybindi
 
 =head1 VERSION
 
-version 0.001_01
+version 0.001
 
 =head1 EXTENDS
 
