@@ -1,9 +1,8 @@
 use Modern::Perl;
 package Renard::Curie::Error;
 # ABSTRACT: Exceptions
-$Renard::Curie::Error::VERSION = '0.001_01'; # TRIAL
-
-$Renard::Curie::Error::VERSION = '0.00101';use custom::failures qw/
+$Renard::Curie::Error::VERSION = '0.001';
+use custom::failures qw/
 	IO::FileNotFound
 	/;
 
@@ -21,7 +20,7 @@ Renard::Curie::Error - Exceptions
 
 =head1 VERSION
 
-version 0.001_01
+version 0.001
 
 =head1 EXTENDS
 
