@@ -1,9 +1,8 @@
 use Renard::Curie::Setup;
 package Renard::Curie::Model::Document::Role::FromFile;
 # ABSTRACT: Role that provides a filename for a document
-$Renard::Curie::Model::Document::Role::FromFile::VERSION = '0.001_01'; # TRIAL
-
-$Renard::Curie::Model::Document::Role::FromFile::VERSION = '0.00101';use Moo::Role;
+$Renard::Curie::Model::Document::Role::FromFile::VERSION = '0.001';
+use Moo::Role;
 use Renard::Curie::Types qw(File);
 
 has filename => (
@@ -26,7 +25,7 @@ Renard::Curie::Model::Document::Role::FromFile - Role that provides a filename f
 
 =head1 VERSION
 
-version 0.001_01
+version 0.001
 
 =head1 ATTRIBUTES
 
