@@ -1,9 +1,8 @@
 use Renard::Curie::Setup;
 package Renard::Curie::Model::Document::Role::Outlineable;
 # ABSTRACT: Role that provides an outline for a document
-$Renard::Curie::Model::Document::Role::Outlineable::VERSION = '0.001_01'; # TRIAL
-
-$Renard::Curie::Model::Document::Role::Outlineable::VERSION = '0.00101';use Moo::Role;
+$Renard::Curie::Model::Document::Role::Outlineable::VERSION = '0.001';
+use Moo::Role;
 use Renard::Curie::Types qw(InstanceOf);
 
 has outline => (
@@ -25,7 +24,7 @@ Renard::Curie::Model::Document::Role::Outlineable - Role that provides an outlin
 
 =head1 VERSION
 
-version 0.001_01
+version 0.001
 
 =head1 ATTRIBUTES
 
