@@ -1,9 +1,8 @@
 use Renard::Curie::Setup;
 package Renard::Curie::Model::Document::Role::Renderable;
 # ABSTRACT: Role for documents that can render their pages
-$Renard::Curie::Model::Document::Role::Renderable::VERSION = '0.001_01'; # TRIAL
-
-$Renard::Curie::Model::Document::Role::Renderable::VERSION = '0.00101';use Moo::Role;
+$Renard::Curie::Model::Document::Role::Renderable::VERSION = '0.001';
+use Moo::Role;
 
 requires 'get_rendered_page';
 
@@ -23,7 +22,7 @@ Renard::Curie::Model::Document::Role::Renderable - Role for documents that can r
 
 =head1 VERSION
 
-version 0.001_01
+version 0.001
 
 =head1 METHODS
 
@@ -37,19 +36,19 @@ The options for this function are:
 
 =over 4
 
-=item * C<<page_number => PageNumber $page_number>>:
+=item * C<page_number>:
 
 The page number to retrieve.
 
-Required. Value must be a C<PageNumber> which must be between the
+Required. Value must be an Int which must be between the
 C<first_page_number> and C<last_page_number>.
 
-=item * C<<zoom_level => ZoomLevel $zoom_level>>:
+=item * C<zoom_level>:
 
 The amount of zoom to use in order to control the dimensions of the
 rendered PDF page. This is C<1.0> by default.
 
-Optional. Value must be a C<ZoomLevel>.
+Optional. Value must be a Float.
 
 =back
 
